@@ -95,7 +95,8 @@ cxx   44 LG=L
       LG=L
 c      CALL FGER1
       CALL FGER1(G,GR,GI,LG,H,JJF)
-      X(II,JJ)=DCMPLX(GR,GI)
+cxx      X(II,JJ)=DCMPLX(GR,GI)
+      X(II,JJ)=CMPLX(GR,GI,KIND=8)
    41 CONTINUE
    40 CONTINUE
 C     INVERSE OF AF (COMPLEX) COMPUTATION
